@@ -26,6 +26,7 @@
 */
 
 #include "mpg321.h"
+#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -112,14 +113,27 @@ void check_default_play_device()
                This causes a delay and is rather annoying, so we'll disable it here
                for now. */
 
+#ifdef HAS_GETENV
             if (getenv("ESD_NO_SPAWN")) unset = 0; /* only unset it later 
                                                       if it's not already set */
+#endif
 
+#ifdef HAS_PUTENV
+	    putenv("ESD_NO_SPAWN=1");
+#else
+#ifdef HAS_SETENV
             setenv("ESD_NO_SPAWN", "1", 0);
-            
+#endif
+#endif
             driver_id = ao_default_driver_id();
 
+#ifdef HAS_PUTENV
+	    if (unset) putenv("ESD_NO_SPAWN");
+#else
+#ifdef HAS_UNSETENV
             if (unset) unsetenv("ESD_NO_SPAWN");
+#endif
+#endif
 
             if (driver_id < 0) {
                 fprintf(stderr, "No default libao driver available.\n");
@@ -202,7 +216,7 @@ void open_ao_playdevice(struct mad_header const *header)
 
         format.bits = 16;
         format.rate = header->samplerate;
-        format.channels = MAD_NCHANNELS(header);
+        format.channels = (options.opt & MPG321_FORCE_STEREO) ? 2 : MAD_NCHANNELS(header);
 
         /* mad gives us little-endian data; we swap it on big-endian targets, to
           big-endian format, because that's what most drivers expect. */
@@ -264,7 +278,7 @@ void open_ao_playdevice(struct mad_header const *header)
             int driver_id = ao_driver_id("null"); 
             /* null is dirty, create a proper options struct later */
 
-            if((playdevice = ao_open_live(driver_id, NULL, NULL)) == NULL)
+            if((playdevice = ao_open_live(driver_id, &format, NULL)) == NULL)
             {
                 fprintf(stderr, "Error opening libao null driver. (This shouldn't have happened.)\n");
                 exit(1);
