@@ -51,6 +51,7 @@ enum mad_flow read_from_mmap(void *data, struct mad_stream *stream)
     if (status != MPG321_REWINDING && playbuf->done)
     {
         status = MPG321_STOPPED;
+        if (options.opt & MPG321_REMOTE_PLAY) printf("@P 0\n");
         return MAD_FLOW_STOP;
     }
 
@@ -199,8 +200,7 @@ enum mad_flow read_header(void *data, struct mad_header const * header)
         current_file[PATH_MAX-1] = '\0';
     }
 
-    current_frame++;
-
+#if 0
     /* I don't know if I agree with this, but it seems to be
        what mpg123 does. I will revert this if anybody complains
        at all. */    
@@ -209,6 +209,11 @@ enum mad_flow read_header(void *data, struct mad_header const * header)
         status = MPG321_STOPPED;
         return MAD_FLOW_STOP;
     }
+#endif
+
+    current_frame++;
+
+    mad_timer_add(&current_time, header->duration);
 
     if(options.opt & MPG321_VERBOSE_PLAY || options.opt & MPG321_REMOTE_PLAY)
     {
@@ -223,27 +228,21 @@ enum mad_flow read_header(void *data, struct mad_header const * header)
                             MAD_UNITS_CENTISECONDS, 0);
     }
                         
-    /* Add the mad_timer after printing out the current information in verbose mode.
-       The theory is, you're currently at the end of a frame, so you display the timestamp
-       at the end of that frame (ie, before_time + length_of_last_frame) - then, increment
-       the current time by the duration of the current frame, and season to taste */
-    mad_timer_add(&current_time, header->duration);
-
     /* update cached table of frames & times */
     if (current_frame <= playbuf->num_frames) /* we only allocate enough for our estimate. */
     {
         playbuf->frames[current_frame] = playbuf->frames[current_frame-1] + (header->bitrate / 8 / 1000)
             * mad_timer_count(header->duration, MAD_UNITS_MILLISECONDS);
         playbuf->times[current_frame] = current_time;
-    }    
-
-    if (status == MPG321_SEEKING && options.seek)
-    {
-        if (!--options.seek)
-            status = MPG321_PLAYING;
-        return MAD_FLOW_IGNORE;
     }
     
+    else
+    {
+        /* We've exceeded our estimate. Printing of any data we have will output crap,
+           so we just return here to make sure we don't cut off the mp3. */
+        return MAD_FLOW_CONTINUE;
+    }    
+
     if (new_file)
     {
         if (options.opt & MPG321_REMOTE_PLAY)
@@ -277,6 +276,18 @@ enum mad_flow read_header(void *data, struct mad_header const * header)
         }
     }
     
+    if (status == MPG321_SEEKING && options.seek)
+    {
+        if (!--options.seek)
+            status = MPG321_PLAYING;
+
+        return MAD_FLOW_IGNORE;
+    }
+    else
+    {
+        status = MPG321_PLAYING;
+    }
+
     if (options.opt & MPG321_VERBOSE_PLAY)
     {
         if (!options.skip_printing_frames 
@@ -777,7 +788,31 @@ enum mad_flow output(void *data,
         ao_play(playdevice, stream, pcm->length * 4);
     }
     
-    else
+    else if (options.opt & MPG321_FORCE_STEREO)
+    {
+        while (nsamples--)
+        {
+            tempsample = (mad_fixed_t)((*left_ch++ * (double)options.volume)/MAD_F_ONE);
+            sample = (signed int) audio_linear_dither(16, tempsample, &dither);
+            
+            /* Just duplicate the sample across both channels. */
+#ifndef WORDS_BIGENDIAN
+            *ptr++ = (unsigned char) (sample >> 0);
+            *ptr++ = (unsigned char) (sample >> 8);
+            *ptr++ = (unsigned char) (sample >> 0);
+            *ptr++ = (unsigned char) (sample >> 8);
+#else
+            *ptr++ = (unsigned char) (sample >> 8);
+            *ptr++ = (unsigned char) (sample >> 0);
+            *ptr++ = (unsigned char) (sample >> 8);
+            *ptr++ = (unsigned char) (sample >> 0);
+#endif
+        }
+
+        ao_play(playdevice, stream, pcm->length * 4);
+    }
+        
+    else /* Just straight mono output */
     {
         while (nsamples--)
         {
@@ -796,4 +831,4 @@ enum mad_flow output(void *data,
     }
 
     return MAD_FLOW_CONTINUE;        
-}
\ No newline at end of file
+}
