@@ -176,6 +176,8 @@ int main(int argc, char *argv[])
         handle_signals(-1); /* initialize signal handler */
      
         signal(SIGINT, handle_signals);
+
+        remote_input_buf[0] = '\0';
     }
     
     if (!(options.opt & MPG321_QUIET_PLAY)) 
@@ -314,11 +316,11 @@ int main(int argc, char *argv[])
             if (dot)
                 *dot = '\0';
             
-            if (strncmp(old_dir, basen, PATH_MAX) != 0)
+            if (status == MPG321_PLAYING)
             {
                 printf("@I %s\n", basen);
                 
-                strncpy(old_dir, basen, PATH_MAX);
+             //   strncpy(old_dir, basen, PATH_MAX);
             }
             
             free(basec);
@@ -343,17 +345,14 @@ int main(int argc, char *argv[])
         if (!(options.opt & MPG321_QUIET_PLAY))
         {
             char time_formatted[11];
-            mad_timer_string(current_time, time_formatted, "%.2u:%.2u", MAD_UNITS_MINUTES,
+            mad_timer_string(current_time, time_formatted, "%.1u:%.2u", MAD_UNITS_MINUTES,
                        MAD_UNITS_SECONDS, 0);
             fprintf(stderr, "\n[%s] Decoding of %s finished.\n",time_formatted, basename(currentfile));
         }
         
-        if (options.opt & MPG321_REMOTE_PLAY)
+        if (options.opt & MPG321_REMOTE_PLAY && status == MPG321_STOPPED)
         {
-            if (status == MPG321_STOPPED)
-                printf("@P 0\n");
-            if (status != MPG321_SEEKING)
-                clear_remote_file(pl);
+            clear_remote_file(pl);
         }
 
         mad_decoder_finish(&decoder);
