@@ -39,7 +39,7 @@
 #include <mad.h>
 
 #define FAKEVERSION "0.59q"
-#define VERSIONDATE "2001/Oct/13"
+#define VERSIONDATE "2001/Nov/30"
 
 /* playlist structure */
 typedef struct pl
@@ -102,6 +102,7 @@ extern int stop_playing_file;
 extern int shuffle_play;
 extern char *playlist_file;
 extern int quit_now;
+extern char remote_input_buf[PATH_MAX + 5];
 
 extern int status;
 
@@ -129,7 +130,8 @@ enum
     MPG321_USE_STDOUT    = 0x0400,
     MPG321_USE_WAV       = 0x0800,
     MPG321_USE_AU        = 0x1000,
-    MPG321_USE_CDR       = 0x2000
+    MPG321_USE_CDR       = 0x2000,
+    MPG321_FORCE_STEREO  = 0x4000
 };
 
 #define DEFAULT_PLAYLIST_SIZE 1024
