@@ -237,7 +237,7 @@ int ftp_open(char * arg)
   int data_sock;
   char ftp_request[1024];
   struct sockaddr_in stLclAddr;
-  size_t namelen;
+  socklen_t namelen;
   int i;
 
   /* Check for URL syntax */
