@@ -43,7 +43,6 @@ void parse_options(int argc, char *argv[], playlist *pl)
         { "headphones", 0, 0, 'O' }, /* or -o h */
         { "speaker", 0, 0, 'P' }, /* or -o s */
         { "lineout", 0, 0, 'L' }, /* or -o l */
-        { "stereo", 0, 0, 'T' },
         { "reopen", 0, 0, 'N' },
         { "equalizer", 0, 0, 'E' },
         { "aggressive", 0, 0, 'I' },
@@ -90,6 +89,7 @@ void parse_options(int argc, char *argv[], playlist *pl)
         { "shuffle", 0, 0, 'z' },
         { "random", 0, 0, 'Z' },
         { "remote", 0, 0, 'R' },
+        { "stereo", 0, 0, 'T' },
             
         /* takes parameters */
         { "skip-printing-frames", 1, 0, 'G' },
@@ -110,7 +110,7 @@ void parse_options(int argc, char *argv[], playlist *pl)
     {            
         switch(c)
         {
-            case 'O': case 'P': case 'L': case 'T': case 'N': case 'E': case '8':
+            case 'O': case 'P': case 'L': case 'N': case 'E': case '8':
             case '2': case '4': case 'c': case 'y': case '0': case '1': case 'm': case 'C':
             case 'u':
             case 'U': case 'n': case 'd': case 'h': case 'f': case 'b': case 'p':
@@ -241,6 +241,10 @@ void parse_options(int argc, char *argv[], playlist *pl)
                 setpriority(PRIO_PROCESS, getpid(), -20);
                 break;
 
+            case 'T':
+                options.opt |= MPG321_FORCE_STEREO;
+                break;
+
             case 'G':
                 options.skip_printing_frames = atoi(optarg);
                 break;
