@@ -31,21 +31,54 @@
 #include <string.h>
 #include <unistd.h>
 
+char remote_input_buf[PATH_MAX + 5];
+
 static
 enum mad_flow remote_parse_input(buffer *buf, playlist *pl)
 {
     char input[PATH_MAX + 5]; /* for filename as well as input and space */
+    char new_remote_input_buf[PATH_MAX + 5];
     char *arg;
     int numread;
+    int alreadyread;
+    int linelen;
 
-    if ((numread = read(0, input, sizeof(input)-1)) == -1)
+    fd_set fd;
+    struct timeval tv = { 0, 0 };
+    FD_ZERO(&fd);
+    FD_SET(0,&fd);
+
+    alreadyread = strlen (remote_input_buf);
+
+    if (select (1, &fd, NULL, NULL, &tv))
     {
-        fprintf(stderr, "remote_parse_input() called with no input queued!");
+      if ((numread = read(0, remote_input_buf + alreadyread, (sizeof(input)-1)-alreadyread)) == -1)
+      {
+        numread = 0;
+        /* fprintf(stderr, "remote_parse_input() called with no input queued!");
         exit(1);
+        This never happens.. (read blocks) */
+      }
+    } else {
+      numread = 0;
     }
 
-    input[numread] = '\0';
+    remote_input_buf[numread+alreadyread] = '\0';
     
+    if (!(arg = strchr(remote_input_buf, '\n')))
+    {
+      return 0;
+    }
+
+    *(arg) = '\0';
+    linelen = strlen (remote_input_buf);
+
+    strcpy (input, remote_input_buf);
+    /* input[linelen] = '\0'; */
+    strcpy (new_remote_input_buf, remote_input_buf + linelen + 1);
+    /* don't copy the \0... */
+    strcpy (remote_input_buf, new_remote_input_buf);
+
     trim_whitespace(input); /* Trims on left and right side only */
 
     if (strlen(input) == 0)
@@ -64,6 +97,7 @@ enum mad_flow remote_parse_input(buffer *buf, playlist *pl)
     {
         if(arg)
         {
+            status = MPG321_PLAYING;
             play_remote_file(pl, arg);
             current_frame = 0;
             options.seek = 0;
@@ -115,12 +149,13 @@ enum mad_flow remote_parse_input(buffer *buf, playlist *pl)
     
     else if (strcasecmp(input, "S") == 0 || strcasecmp(input, "STOP") == 0)
     {
-        if (status != MPG321_STOPPED) /* i.e., if we're playing */
+        if (status != MPG321_STOPPED)
         {
             status = MPG321_STOPPED;
             clear_remote_file(pl);
             current_frame = 0;
             pause_play(NULL, NULL); /* reset pause data */
+            printf("@P 0\n");
         }
         
         goto stop;
@@ -164,8 +199,12 @@ void remote_get_input_wait(buffer *buf)
     FD_ZERO(&fd);
     FD_SET(0,&fd);
     
-    if (select(1, &fd, NULL, NULL, NULL))
-        remote_parse_input(buf, buf->pl);
+    if (!strlen (remote_input_buf))
+    {
+      select(1, &fd, NULL, NULL, NULL);
+    }
+
+    remote_parse_input(buf, buf->pl);
 }
 
 enum mad_flow remote_get_input_nowait(buffer *buf)
@@ -174,9 +213,18 @@ enum mad_flow remote_get_input_nowait(buffer *buf)
     struct timeval tv = { 0, 0 };
     FD_ZERO(&fd);
     FD_SET(0,&fd);
-    
-    if (select(1, &fd, NULL, NULL, &tv))
+
+    if (!strlen (remote_input_buf))
+    {
+        if (select(1, &fd, NULL, NULL, &tv))
+            return remote_parse_input(buf, buf->pl);
+
+        else
+            return 0;
+    } 
+     
+    else 
+    {
         return remote_parse_input(buf, buf->pl);
-    else
-        return 0;
+    }
 }
